@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'pathname'
 require 'yaml'
 
@@ -6,19 +8,23 @@ require 'rubocop'
 require_relative 'rubocop/rspec'
 require_relative 'rubocop/rspec/version'
 require_relative 'rubocop/rspec/inject'
+require_relative 'rubocop/rspec/node'
 require_relative 'rubocop/rspec/top_level_describe'
 require_relative 'rubocop/rspec/wording'
-require_relative 'rubocop/rspec/util'
 require_relative 'rubocop/rspec/language'
 require_relative 'rubocop/rspec/language/node_pattern'
+require_relative 'rubocop/rspec/top_level_group'
 require_relative 'rubocop/rspec/concept'
 require_relative 'rubocop/rspec/example_group'
 require_relative 'rubocop/rspec/example'
 require_relative 'rubocop/rspec/hook'
+require_relative 'rubocop/rspec/variable'
 require_relative 'rubocop/cop/rspec/cop'
 require_relative 'rubocop/rspec/align_let_brace'
-require_relative 'rubocop/rspec/capybara'
 require_relative 'rubocop/rspec/factory_bot'
+require_relative 'rubocop/rspec/final_end_location'
+require_relative 'rubocop/rspec/blank_line_separation'
+require_relative 'rubocop/rspec/corrector/move_node'
 
 RuboCop::RSpec::Inject.defaults!
 
@@ -38,3 +44,5 @@ module RuboCop
     end
   end
 end
+
+RuboCop::AST::Node.include(RuboCop::RSpec::Node)
