@@ -18,18 +18,15 @@ module RuboCop
       #   end
       class DescribeMethod < Cop
         include RuboCop::RSpec::TopLevelDescribe
-        include RuboCop::RSpec::Util
 
         MSG = 'The second argument to describe should be the method '\
-              "being tested. '#instance' or '.class'.".freeze
-
-        METHOD_STRING_MATCHER = /\A[\#\.].+/
+              "being tested. '#instance' or '.class'."
 
         def on_top_level_describe(_node, (_, second_arg))
-          return unless second_arg && second_arg.str_type?
-          return if METHOD_STRING_MATCHER =~ one(second_arg.children)
+          return unless second_arg&.str_type?
+          return if second_arg.str_content.start_with?('#', '.')
 
-          add_offense(second_arg, location: :expression)
+          add_offense(second_arg)
         end
       end
     end
