@@ -8,25 +8,25 @@ module RuboCop
       # @example
       #   # bad
       #   describe :my_method do
-      #     ...
+      #     # ...
       #   end
       #
       #   # good
       #   describe '#my_method' do
-      #     ...
+      #     # ...
       #   end
       #
       # @see https://github.com/rspec/rspec-core/issues/1610
       class DescribeSymbol < Cop
-        MSG = 'Avoid describing symbols.'.freeze
+        MSG = 'Avoid describing symbols.'
 
         def_node_matcher :describe_symbol?, <<-PATTERN
-          (send {(const nil? :RSpec) nil?} :describe $sym ...)
+          (send #{RSPEC} :describe $sym ...)
         PATTERN
 
         def on_send(node)
           describe_symbol?(node) do |match|
-            add_offense(match, location: :expression)
+            add_offense(match)
           end
         end
       end
