@@ -15,23 +15,20 @@ module RuboCop
       #
       #   let(:foo) { bar }
       class EmptyLineAfterSubject < Cop
-        MSG = 'Add empty line after `subject`.'.freeze
+        extend AutoCorrector
+        include RuboCop::RSpec::BlankLineSeparation
 
-        def_node_matcher :subject?, '(block $(send nil? :subject ...) args ...)'
+        MSG = 'Add empty line after `subject`.'
 
         def on_block(node)
           return unless subject?(node) && !in_spec_block?(node)
-          return if node.equal?(node.parent.children.last)
+          return if last_child?(node)
 
-          send_line = node.loc.end.line
-          next_line = processed_source[send_line]
-          return if next_line.blank?
-
-          add_offense(node, location: :expression, message: MSG)
-        end
-
-        def autocorrect(node)
-          ->(corrector) { corrector.insert_after(node.loc.end, "\n") }
+          missing_separating_line(node) do |location|
+            add_offense(location) do |corrector|
+              corrector.insert_after(location.end, "\n")
+            end
+          end
         end
 
         private
