@@ -28,7 +28,7 @@ module RuboCop
       class ExampleLength < Cop
         include CodeLength
 
-        MSG = 'Example has too many lines [%<total>d/%<max>d].'.freeze
+        MSG = 'Example has too many lines [%<total>d/%<max>d].'
 
         def on_block(node)
           return unless example?(node)
@@ -37,7 +37,7 @@ module RuboCop
 
           return unless length > max_length
 
-          add_offense(node, location: :expression, message: message(length))
+          add_offense(node, message: message(length))
         end
 
         private
