@@ -20,31 +20,29 @@ module RuboCop
       #   describe MyClass do
       #   end
       class Focus < Cop
-        MSG = 'Focused spec found.'.freeze
+        MSG = 'Focused spec found.'
 
         focusable =
           ExampleGroups::GROUPS  +
           ExampleGroups::SKIPPED +
           Examples::EXAMPLES     +
-          Examples::SKIPPED
+          Examples::SKIPPED      +
+          Examples::PENDING
 
         focused = ExampleGroups::FOCUSED + Examples::FOCUSED
 
         FOCUSABLE_SELECTORS = focusable.node_pattern_union
 
-        FOCUS_SYMBOL = s(:sym, :focus)
-        FOCUS_TRUE   = s(:pair, FOCUS_SYMBOL, s(:true))
-
         def_node_matcher :metadata, <<-PATTERN
-          {(send nil? #{FOCUSABLE_SELECTORS} ... (hash $...))
-           (send nil? #{FOCUSABLE_SELECTORS} $...)}
+          {(send #{RSPEC} #{FOCUSABLE_SELECTORS} <$(sym :focus) ...>)
+           (send #{RSPEC} #{FOCUSABLE_SELECTORS} ... (hash <$(pair (sym :focus) true) ...>))}
         PATTERN
 
         def_node_matcher :focused_block?, focused.send_pattern
 
         def on_send(node)
           focus_metadata(node) do |focus|
-            add_offense(focus, location: :expression)
+            add_offense(focus)
           end
         end
 
@@ -53,10 +51,7 @@ module RuboCop
         def focus_metadata(node, &block)
           yield(node) if focused_block?(node)
 
-          metadata(node) do |matches|
-            matches.grep(FOCUS_SYMBOL, &block)
-            matches.grep(FOCUS_TRUE, &block)
-          end
+          metadata(node, &block)
         end
       end
     end
