@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module RuboCop
   module Cop
     module RSpec
@@ -14,15 +16,16 @@ module RuboCop
       #   # good
       #   expect(foo).to be_something
       class InvalidPredicateMatcher < Cop
-        MSG = 'Omit `?` from `%<matcher>s`.'.freeze
+        MSG = 'Omit `?` from `%<matcher>s`.'
 
         def_node_matcher :invalid_predicate_matcher?, <<-PATTERN
-          (send (send nil? :expect ...) {:to :not_to :to_not} $(send nil? #predicate?))
+          (send (send nil? :expect ...) #{Runners::ALL.node_pattern_union} $(send nil? #predicate?))
         PATTERN
 
         def on_send(node)
           invalid_predicate_matcher?(node) do |predicate|
-            add_offense(predicate, location: :expression)
+            add_offense(predicate,
+                        message: format(MSG, matcher: predicate.method_name))
           end
         end
 
@@ -32,10 +35,6 @@ module RuboCop
           name = name.to_s
           name.start_with?('be_', 'have_') && name.end_with?('?')
         end
-
-        def message(predicate)
-          format(MSG, matcher: predicate.method_name)
-        end
       end
     end
   end
