@@ -19,23 +19,22 @@ module RuboCop
       #   # good
       #   it_should_behave_like 'a foo'
       class ItBehavesLike < Cop
+        extend AutoCorrector
         include ConfigurableEnforcedStyle
 
         MSG = 'Prefer `%<replacement>s` over `%<original>s` when including '\
-              'examples in a nested context.'.freeze
+              'examples in a nested context.'
 
         def_node_matcher :example_inclusion_offense, '(send _ % ...)'
 
         def on_send(node)
           example_inclusion_offense(node, alternative_style) do
-            add_offense(node, location: :expression)
+            add_offense(node) do |corrector|
+              corrector.replace(node.loc.selector, style.to_s)
+            end
           end
         end
 
-        def autocorrect(node)
-          ->(corrector) { corrector.replace(node.loc.selector, style.to_s) }
-        end
-
         private
 
         def message(_node)
