@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module RuboCop
   module Cop
     module RSpec
@@ -15,7 +17,7 @@ module RuboCop
       #   end
       class IteratedExpectation < Cop
         MSG = 'Prefer using the `all` matcher instead ' \
-                  'of iterating over an array.'.freeze
+                  'of iterating over an array.'
 
         def_node_matcher :each?, <<-PATTERN
           (block
@@ -32,7 +34,7 @@ module RuboCop
         def on_block(node)
           each?(node) do |arg, body|
             if single_expectation?(body, arg) || only_expectations?(body, arg)
-              add_offense(node.children.first, location: :expression)
+              add_offense(node.send_node)
             end
           end
         end
