@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module RuboCop
   module Cop
     module RSpec
@@ -14,22 +16,21 @@ module RuboCop
       #     expect(false).not_to be_true
       #   end
       class NotToNot < Cop
+        extend AutoCorrector
         include ConfigurableEnforcedStyle
 
-        MSG = 'Prefer `%<replacement>s` over `%<original>s`.'.freeze
+        MSG = 'Prefer `%<replacement>s` over `%<original>s`.'
 
         def_node_matcher :not_to_not_offense, '(send _ % ...)'
 
         def on_send(node)
           not_to_not_offense(node, alternative_style) do
-            add_offense(node, location: :expression)
+            add_offense(node.loc.selector) do |corrector|
+              corrector.replace(node.loc.selector, style.to_s)
+            end
           end
         end
 
-        def autocorrect(node)
-          ->(corrector) { corrector.replace(node.loc.selector, style.to_s) }
-        end
-
         private
 
         def message(_node)
