@@ -22,11 +22,10 @@ module RuboCop
       #   let(:baz) { baz }
       #   let!(:other) { other }
       class OverwritingSetup < Cop
-        MSG = '`%<name>s` is already defined.'.freeze
+        MSG = '`%<name>s` is already defined.'
 
-        def_node_matcher :setup?, <<-PATTERN
-          (block (send nil? {:let :let! :subject} (sym $_)) ...)
-        PATTERN
+        def_node_matcher :setup?, (Helpers::ALL + Subject::ALL).block_pattern
+        def_node_matcher :first_argument_name, '(send _ _ ({str sym} $_))'
 
         def on_block(node)
           return unless example_group_with_body?(node)
@@ -34,7 +33,6 @@ module RuboCop
           find_duplicates(node.body) do |duplicate, name|
             add_offense(
               duplicate,
-              location: :expression,
               message: format(MSG, name: name)
             )
           end
@@ -44,12 +42,26 @@ module RuboCop
 
         def find_duplicates(node)
           setup_expressions = Set.new
-          node.each_child_node do |child|
-            setup?(child) do |name|
-              yield child, name unless setup_expressions.add?(name)
-            end
+          node.each_child_node(:block) do |child|
+            next unless common_setup?(child)
+
+            name = if child.send_node.arguments?
+                     first_argument_name(child.send_node).to_sym
+                   else
+                     :subject
+                   end
+
+            yield child, name unless setup_expressions.add?(name)
           end
         end
+
+        def common_setup?(node)
+          return false unless setup?(node)
+
+          # Search only for setup with basic_literal arguments (e.g. :sym, :str)
+          # or no arguments at all.
+          node.send_node.arguments.all?(&:basic_literal?)
+        end
       end
     end
   end
