@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module RuboCop
   module Cop
     module RSpec
@@ -14,13 +16,13 @@ module RuboCop
       #    end
       #
       class RepeatedExample < Cop
-        MSG = "Don't repeat examples within an example group.".freeze
+        MSG = "Don't repeat examples within an example group."
 
         def on_block(node)
           return unless example_group?(node)
 
           repeated_examples(node).each do |repeated_example|
-            add_offense(repeated_example, location: :expression)
+            add_offense(repeated_example)
           end
         end
 
