@@ -27,9 +27,9 @@ module RuboCop
       #   end
       #
       class ScatteredLet < Cop
-        MSG = 'Group all let/let! blocks in the example group together.'.freeze
+        extend AutoCorrector
 
-        def_node_matcher :let?, '(block (send nil? {:let :let!} ...) ...)'
+        MSG = 'Group all let/let! blocks in the example group together.'
 
         def on_block(node)
           return unless example_group_with_body?(node)
@@ -45,9 +45,18 @@ module RuboCop
           first_let = lets.first
           lets.each_with_index do |node, idx|
             next if node.sibling_index == first_let.sibling_index + idx
-            add_offense(node, location: :expression)
+
+            add_offense(node) do |corrector|
+              RuboCop::RSpec::Corrector::MoveNode.new(
+                node, corrector, processed_source
+              ).move_after(first_let)
+            end
           end
         end
+
+        def find_first_let(node)
+          node.children.find { |child| let?(child) }
+        end
       end
     end
   end
