@@ -13,7 +13,7 @@ module RuboCop
       #   expect(something).to be(1)
       class VoidExpect < Cop
         MSG = 'Do not use `expect()` without `.to` or `.not_to`. ' \
-              'Chain the methods or remove it.'.freeze
+              'Chain the methods or remove it.'
 
         def_node_matcher :expect?, <<-PATTERN
           (send nil? :expect ...)
@@ -25,11 +25,13 @@ module RuboCop
 
         def on_send(node)
           return unless expect?(node)
+
           check_expect(node)
         end
 
         def on_block(node)
           return unless expect_block?(node)
+
           check_expect(node)
         end
 
@@ -37,14 +39,15 @@ module RuboCop
 
         def check_expect(node)
           return unless void?(node)
-          add_offense(node, location: :expression)
+
+          add_offense(node)
         end
 
         def void?(expect)
           parent = expect.parent
           return true unless parent
           return true if parent.begin_type?
-          return true if parent.block_type? && parent.children[2] == expect
+          return true if parent.block_type? && parent.body == expect
         end
       end
     end
