@@ -1,11 +1,13 @@
+# frozen_string_literal: true
+
 require 'yaml'
 
 module RuboCop
   module RSpec
     # Builds a YAML config file from two config hashes
     class ConfigFormatter
-      NAMESPACES = /^(#{Regexp.union('RSpec', 'Capybara', 'FactoryBot')})/
-      STYLE_GUIDE_BASE_URL = 'http://www.rubydoc.info/gems/rubocop-rspec/RuboCop/Cop/RSpec/'.freeze
+      NAMESPACES = /^(RSpec|Capybara|FactoryBot|Rails)/.freeze
+      STYLE_GUIDE_BASE_URL = 'https://www.rubydoc.info/gems/rubocop-rspec/RuboCop/Cop/RSpec/'
 
       def initialize(config, descriptions)
         @config       = config
