@@ -4,7 +4,7 @@ module RuboCop
   module RSpec
     # Wrapper for RSpec examples
     class Example < Concept
-      def_node_matcher :extract_doc_string,     '(send _ _ $str ...)'
+      def_node_matcher :extract_doc_string,     '(send _ _ $_ ...)'
       def_node_matcher :extract_metadata,       '(send _ _ _ $...)'
       def_node_matcher :extract_implementation, '(block send args $_)'
 
@@ -24,7 +24,7 @@ module RuboCop
         if node.send_type?
           node
         else
-          node.children.first
+          node.send_node
         end
       end
     end
