@@ -1,27 +1,22 @@
+# frozen_string_literal: true
+
 module RuboCop
   module RSpec
     # Helper methods for top level describe cops
     module TopLevelDescribe
       extend NodePattern::Macros
 
-      def_node_matcher :described_constant, <<-PATTERN
-        (block $(send _ :describe $(const ...)) (args) $_)
-      PATTERN
-
       def on_send(node)
         return unless respond_to?(:on_top_level_describe)
         return unless top_level_describe?(node)
 
-        _receiver, _method_name, *args = *node
-
-        on_top_level_describe(node, args)
+        on_top_level_describe(node, node.arguments)
       end
 
       private
 
       def top_level_describe?(node)
-        _receiver, method_name, *_args = *node
-        return false unless method_name == :describe
+        return false unless node.method_name == :describe
 
         top_level_nodes.include?(node)
       end
@@ -49,7 +44,7 @@ module RuboCop
 
       def describe_statement_children(node)
         node.each_child_node(:send).select do |element|
-          element.children[1] == :describe
+          element.method_name == :describe
         end
       end
     end
