@@ -1,5 +1,7 @@
-RSpec.describe RuboCop::Cop::RSpec::BeforeAfterAll, :config do
-  subject(:cop) { described_class.new(config) }
+# frozen_string_literal: true
+
+RSpec.describe RuboCop::Cop::RSpec::BeforeAfterAll do
+  subject(:cop) { described_class.new }
 
   def message(hook)
     "Beware of using `#{hook}` as it may cause state to leak between tests. "\
