@@ -1,13 +1,32 @@
-RSpec.describe RuboCop::Cop::RSpec::NotToNot, :config do
-  subject(:cop) { described_class.new(config) }
+# frozen_string_literal: true
 
+RSpec.describe RuboCop::Cop::RSpec::NotToNot, :config do
   context 'when EnforcedStyle is `not_to`' do
     let(:cop_config) { { 'EnforcedStyle' => 'not_to' } }
 
     it 'detects the `to_not` offense' do
       expect_offense(<<-RUBY)
         it { expect(false).to_not be_true }
-             ^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Prefer `not_to` over `to_not`.
+                           ^^^^^^ Prefer `not_to` over `to_not`.
+      RUBY
+
+      expect_correction(<<-RUBY)
+        it { expect(false).not_to be_true }
+      RUBY
+    end
+
+    it 'detects the `to_not` offense on an expect block' do
+      expect_offense(<<-RUBY)
+        expect {
+          2 + 2
+        }.to_not raise_error
+          ^^^^^^ Prefer `not_to` over `to_not`.
+      RUBY
+
+      expect_correction(<<-RUBY)
+        expect {
+          2 + 2
+        }.not_to raise_error
       RUBY
     end
 
@@ -16,10 +35,6 @@ RSpec.describe RuboCop::Cop::RSpec::NotToNot, :config do
         it { expect(false).not_to be_true }
       RUBY
     end
-
-    include_examples 'autocorrect',
-                     'it { expect(0).to_not equal 1 }',
-                     'it { expect(0).not_to equal 1 }'
   end
 
   context 'when AcceptedMethod is `to_not`' do
@@ -28,7 +43,26 @@ RSpec.describe RuboCop::Cop::RSpec::NotToNot, :config do
     it 'detects the `not_to` offense' do
       expect_offense(<<-RUBY)
         it { expect(false).not_to be_true }
-             ^^^^^^^^^^^^^^^^^^^^^^^^^^^^ Prefer `to_not` over `not_to`.
+                           ^^^^^^ Prefer `to_not` over `not_to`.
+      RUBY
+
+      expect_correction(<<-RUBY)
+        it { expect(false).to_not be_true }
+      RUBY
+    end
+
+    it 'detects the `not_to` offense on an expect block' do
+      expect_offense(<<-RUBY)
+        expect {
+          2 + 2
+        }.not_to raise_error
+          ^^^^^^ Prefer `to_not` over `not_to`.
+      RUBY
+
+      expect_correction(<<-RUBY)
+        expect {
+          2 + 2
+        }.to_not raise_error
       RUBY
     end
 
@@ -37,9 +71,5 @@ RSpec.describe RuboCop::Cop::RSpec::NotToNot, :config do
         it { expect(false).to_not be_true }
       RUBY
     end
-
-    include_examples 'autocorrect',
-                     'it { expect(0).not_to equal 1 }',
-                     'it { expect(0).to_not equal 1 }'
   end
 end
