@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 RSpec.describe RuboCop::Cop::RSpec::OverwritingSetup do
   subject(:cop) { described_class.new }
 
@@ -22,6 +24,17 @@ RSpec.describe RuboCop::Cop::RSpec::OverwritingSetup do
     RUBY
   end
 
+  it 'works with `subject!` and `let!`' do
+    expect_offense(<<-RUBY)
+      RSpec.describe User do
+        subject!(:a) { a }
+
+        let!(:a) { b }
+        ^^^^^^^^^^^^^^ `a` is already defined.
+      end
+    RUBY
+  end
+
   it 'finds `let!` overwriting `let`' do
     expect_offense(<<-RUBY)
       RSpec.describe User do
@@ -44,8 +57,35 @@ RSpec.describe RuboCop::Cop::RSpec::OverwritingSetup do
     RUBY
   end
 
-  it 'does not encounter an error when handling an empty describe' do
-    expect { inspect_source('RSpec.describe(User) do end', 'a_spec.rb') }
-      .not_to raise_error
+  it 'handles unnamed subjects' do
+    expect_offense(<<-RUBY)
+      RSpec.describe User do
+        subject { a }
+
+        let(:subject) { b }
+        ^^^^^^^^^^^^^^^^^^^ `subject` is already defined.
+      end
+    RUBY
+  end
+
+  it 'handles dynamic names for `let`' do
+    expect_no_offenses(<<-RUBY)
+      RSpec.describe User do
+        subject(:name) { a }
+
+        let(name) { b }
+      end
+    RUBY
+  end
+
+  it 'handles string arguments' do
+    expect_offense(<<-RUBY)
+      RSpec.describe User do
+        subject(:name) { a }
+
+        let("name") { b }
+        ^^^^^^^^^^^^^^^^^ `name` is already defined.
+      end
+    RUBY
   end
 end
