@@ -1,8 +1,10 @@
+# frozen_string_literal: true
+
 require 'rubocop'
 
 require 'rubocop/rspec/support'
 
-if ENV['CI']
+if ENV['COVERAGE'] == 'true'
   require 'simplecov'
   SimpleCov.start
 end
@@ -15,16 +17,12 @@ spec_helper_glob = File.expand_path('{support,shared}/*.rb', __dir__)
 Dir.glob(spec_helper_glob).map(&method(:require))
 
 RSpec.configure do |config|
+  config.define_derived_metadata(file_path: %r{/spec/rubocop/cop/}) do |meta|
+    meta[:type] = :cop_spec
+  end
+
   config.order = :random
 
-  config.expect_with :rspec do |expectations|
-    expectations.syntax = :expect # Disable `should`
-  end
-
-  config.mock_with :rspec do |mocks|
-    mocks.syntax = :expect # Disable `should_receive` and `stub`
-  end
-
   # Forbid RSpec from monkey patching any of our objects
   config.disable_monkey_patching!
 
